# LaTeX Workshop Demo

########################################################################################################
# Exporting Plots to Particular Directories
########################################################################################################
  require(ggplot2)

# First, Let's make a silly demo plot
  
  google.hits <- c(345000000, 1610000, 16000, 143000, 870, 439)
  ys.in.mayya <- c(1, 2, 3, 4, 5, 6)
  
  pdat <- as.data.frame(cbind(google.hits, ys.in.mayya))
  p <- ggplot(pdat, aes(x = ys.in.mayya, y = google.hits))
  p <- p + geom_point(colour = "dodgerblue2", size = 3) + xlab("Y's in \"Mayya\"") + ylab("Google Hits") + ggtitle("Google Hits")
  
  setwd("~/Dropbox/Teaching/Personal Drafts/LaTeX Workshop/Other Graphics")
  
  pdf("ghits.pdf")
  p
  dev.off()
  
########################################################################################################
# Exporting Tables with Stargazer
########################################################################################################
# Let's make some objects we can format in Stargazer
  
  # First, some "data" for a regression
  
    x1 <- rpois(10000, lambda = 9)
    x2 <- runif(10000, 75, 350)
    y <- 6 + 14 * x1 + 3 * x2 + rnorm(10000, 0, 5)
    
  # Let's run our regression (fun quiz: what should the coefficients be?)
    
    reg1 <- lm(y ~ x1 + x2)
    
  # Let's make a non-regression object that proves you can do this with regular data frames
    
    summary <- as.data.frame(rbind(apply(cbind(x1, x2, y), 2, mean), 
                                   apply(cbind(x1, x2, y), 2, sd), 
                                   apply(cbind(x1, x2, y), 2, max),
                                   apply(cbind(x1, x2, y), 2, min)))
    
# Ok Let's fire up Stargazer
  require(stargazer)
    
# And set our working directory to the tables folder
  setwd("~/Dropbox/Teaching/Personal Drafts/LaTeX Workshop/Stargazer")
    
# So let's print some tables
  
  # Before I start formatting anything, here's some basic output from stargazer. 
  # All I'm doing here is setting the filename
    stargazer(reg1, out = "basicreg.tex")
    
  # Now let's add some formatting. Let's say I wanted to label my independent
  # and dependent variables right in R
    stargazer(reg1, out = "reglabels.tex",
              covariate.labels = c("Ice Cream Bars Sold", "Temperature"), # for the covars, in order
              dep.var.labels = "Swimming Pool Deaths",
              dep.var.caption = "Time to Sit Back and Unwind?", # you can change the label above your depvar
              label = "star2", # this sets the reference label for your figure so you can refer to it in your doc
              title = "The Most Wonderful Time of the Year") 
    
    
  # I may want to modify the statistics I'm reporting. There are a couple of ways to do this
  # The first way is fully manual. I can just give stargazer a list of what I want to see using the
  # report option. Here's what report takes on:  "v", "c", "s","t", "p", "*"
  #  that determines whether, and in which order, variable names ("v"), coefficients
  #  ("c"), standard errors/confidence intervals ("s"), test statistics ("t") and pvalues
  #  ("p") should be reported in regression tables. If one of the aforementioned
  #  letters is followed by an asterisk ("*"), significance stars will be reported
  #  next to the corresponding statistic.
    
    stargazer(reg1, out = "newstats.tex",
              covariate.labels = c("Ice Cream Bars Sold", "Temperature"), # for the covars, in order
              dep.var.labels = "Swimming Pool Deaths",
              dep.var.caption = "Time to Sit Back and Unwind?", # you can change the label above your depvar
              label = "star3",
              report = "vcstp*",
              title = "The Most Wonderful Time of the Year")
    
    
  # I can also achieve this by selecting an entire style type for my table using the style option
  # see p. 22 here: https://cran.r-project.org/web/packages/stargazer/stargazer.pdf for available options
    
    stargazer(reg1, out = "apsr.tex",
              covariate.labels = c("Ice Cream Bars Sold", "Temperature"), # for the covars, in order
              dep.var.labels = "Swimming Pool Deaths",
              dep.var.caption = "Time to Sit Back and Unwind?", # you can change the label above your depvar
              label = "star4",
              style = "apsr", # this lets you set your appearance directly to a journal style
              title = "The Most Wonderful Time of the Year") 
    
  # I can modify the spacing in my table manually. I can remove all empty row space using no.space = T
  # and put regression se's on a single row with coefs using single.row = T
    stargazer(reg1, out = "spacing.tex",
              covariate.labels = c("Ice Cream Bars Sold", "Temperature"), # for the covars, in order
              dep.var.labels = "Swimming Pool Deaths",
              dep.var.caption = "Time to Sit Back and Unwind?", # you can change the label above your depvar
              label = "star5",
              report = "vcstp*",
              no.space = T, 
              single.row = T,
              title = "The Most Wonderful Time of the Year")
    
    # Finally, I can make sure that my stargazer table is in a float environment and set its table position
    # using float = T and table.placement
    stargazer(reg1, out = "floatie.tex",
              covariate.labels = c("Ice Cream Bars Sold", "Temperature"), # for the covars, in order
              dep.var.labels = "Swimming Pool Deaths",
              dep.var.caption = "Time to Sit Back and Unwind?", # you can change the label above your depvar
              label = "star6",
              report = "vcstp*",
              no.space = T, 
              single.row = T,
              float = T,
              table.placement = "h!",
              title = "The Most Wonderful Time of the Year")
    
  
    
    